==> gazie7.30.zip: gazie/modules/magazz/report_ragstat.php <==
<?php
/*
 --------------------------------------------------------------------------
                            GAzie - Gestione Azienda
    Copyright (C) 2004-2020 - Antonio De Vincentiis Montesilvano (PE)
         (http://www.devincentiis.it)
           <http://gazie.sourceforge.net>
 --------------------------------------------------------------------------
    Questo programma e` free software;   e` lecito redistribuirlo  e/o
    modificarlo secondo i  termini della Licenza Pubblica Generica GNU
    come e` pubblicata dalla Free Software Foundation; o la versione 2
    della licenza o (a propria scelta) una versione successiva.

    Questo programma  e` distribuito nella speranza  che sia utile, ma
    SENZA   ALCUNA GARANZIA; senza  neppure  la  garanzia implicita di
    NEGOZIABILITA` o di  APPLICABILITA` PER UN  PARTICOLARE SCOPO.  Si
    veda la Licenza Pubblica Generica GNU per avere maggiori dettagli.

    Ognuno dovrebbe avere   ricevuto una copia  della Licenza Pubblica
    Generica GNU insieme a   questo programma; in caso  contrario,  si
    scriva   alla   Free  Software Foundation, 51 Franklin Street,
    Fifth Floor Boston, MA 02110-1335 USA Stati Uniti.
 --------------------------------------------------------------------------
*/
require("../../library/include/datlib.inc.php");

$admin_aziend=checkAdmin();
$titolo = 'Categorie Merceologiche';
require("../../library/include/header.php");
$script_transl =HeadMain();

if (isset($_GET['auxil'])) {
   $auxil = $_GET['auxil'];
}
if (isset($_GET['all'])) {
   $auxil = "&all=yes";
   $where = "descri like '%'";
   $passo = 100000;
} else {
   if (isset($_GET['auxil'])) {
      $where = "descri like '".addslashes($_GET['auxil'])."%'";
   }
}

if (!isset($_GET['auxil'])) {
   $auxil = "";
   $where = "descri like '".addslashes($auxil)."%'";
}
?>
<div align="center" class="FacetFormHeaderFont">Raggruppamenti statistici</div>
<?php
$recordnav = new recordnav($gTables['ragstat'], $where, $limit, $passo);
$recordnav -> output();

/** ENRICO FEDELE */
/* pulizia del codice, eliminato boxover, aggiunte classi bootstrap alla tabella, convertite immagini in glyphicons */
?>
<form method="GET" action="<?php echo $_SERVER['PHP_SELF']; ?>">
<table class="Tlarge table table-striped table-bordered table-condensed table-responsive">
    <thead>
        <tr>
        	<td></td>
        	<td class="FacetFieldCaptionTD">Descrizione:
        		<input type="text" name="auxil" value="<?php if ($auxil != "&all=yes") echo $auxil; ?>" maxlength="6" size="3" tabindex="1" class="FacetInput">
        	</td>
        	<td>
        		<input type="submit" name="search" value="Cerca" tabindex="1" onClick="javascript:document.report.all.value=1;">
        	</td>
        	<td>
        		<input type="submit" name="all" value="Mostra tutti" onClick="javascript:document.report.all.value=1;">
        	</td>
        </tr>
        <tr>
<?php
$result = gaz_dbi_dyn_query ('*', $gTables['ragstat'], $where, $orderby, $limit, $passo);
// creo l'array (header => campi) per l'ordinamento dei record
$headers_ragstat = array  (
            "Codice" => "codice",
            "Descrizione" => "descri",
            "% Ricarico" => "ricarico",
            "Annotazioni" => "annota",
            "Cancella" => ""
            );
$linkHeaders = new linkHeaders($headers_ragstat);
$linkHeaders -> output();
?>
		</tr>
	</thead>
	<tbody>
<?php
while ($a_row = gaz_dbi_fetch_array($result)) {
    /*if(!isset($_GET['all']) and !empty($a_row["image"])){
            $boxover = "title=\"cssbody=[FacetInput] cssheader=[FacetButton] header=[{$a_row['annota']}] body=[<center><img src='../root/view.php?table=ragstat&value=".$a_row['codice']."'>] fade=[on] fadespeed=[0.03] \"";
    } else {
            $boxover = "title=\"cssbody=[FacetInput] cssheader=[FacetButton] header=[{$a_row['annota']}]  fade=[on] fadespeed=[0.03] \"";
    }*/
    echo '		<tr>
				<td class="FacetDataTD">
					<a class="btn btn-xs btn-default btn-block" href="admin_ragstat.php?Update&codice='.$a_row["codice"].'">
						<i class="glyphicon glyphicon-edit"></i>&nbsp;'.$a_row["codice"].'
					</a>
				</td>
				<td class="FacetDataTD">
					<span class="gazie-tooltip" data-type="ragstat-thumb" data-id="'.$a_row['codice'].'" data-title="'.$a_row['annota'].'">'.$a_row["descri"].'</span>
				</td>
				<td class="FacetDataTD">'.$a_row["ricarico"].'</td>
				<td class="FacetDataTD">'.$a_row["annota"].'</td>
				<td class="FacetDataTD">
					<a class="btn btn-xs btn-default btn-elimina" href="delete_ragstat.php?codice='.$a_row["codice"].'">
						<i class="glyphicon glyphicon-remove"></i>
					</a>
				</td>
			</tr>';
}
?>
			</tbody>
		</table>
	<?php
require("../../library/include/footer.php");
?>
<!--<script src="../../js/boxover/boxover.js"></script>-->

==> gazie8.00.zip: gazie/modules/magazz/report_ragstat.php <==
<?php
/*
 --------------------------------------------------------------------------
                            GAzie - Gestione Azienda
    Copyright (C) 2004-2021 - Antonio De Vincentiis Montesilvano (PE)
         (http://www.devincentiis.it)
           <http://gazie.sourceforge.net>
 --------------------------------------------------------------------------
    Questo programma e` free software;   e` lecito redistribuirlo  e/o
    modificarlo secondo i  termini della Licenza Pubblica Generica GNU
    come e` pubblicata dalla Free Software Foundation; o la versione 2
    della licenza o (a propria scelta) una versione successiva.

    Questo programma  e` distribuito nella speranza  che sia utile, ma
    SENZA   ALCUNA GARANZIA; senza  neppure  la  garanzia implicita di
    NEGOZIABILITA` o di  APPLICABILITA` PER UN  PARTICOLARE SCOPO.  Si
    veda la Licenza Pubblica Generica GNU per avere maggiori dettagli.

    Ognuno dovrebbe avere   ricevuto una copia  della Licenza Pubblica
    Generica GNU insieme a   questo programma; in caso  contrario,  si
    scriva   alla   Free  Software Foundation, 51 Franklin Street,
    Fifth Floor Boston, MA 02110-1335 USA Stati Uniti.
 --------------------------------------------------------------------------
*/
require("../../library/include/datlib.inc.php");

$admin_aziend=checkAdmin();
$titolo = 'Categorie Merceologiche';
require("../../library/include/header.php");
$script_transl =HeadMain();

if (isset($_GET['auxil'])) {
   $auxil = $_GET['auxil'];
}
if (isset($_GET['all'])) {
   $auxil = "&all=yes";
   $where = "descri like '%'";
   $passo = 100000;
} else {
   if (isset($_GET['auxil'])) {
      $where = "descri like '".addslashes($_GET['auxil'])."%'";
   }
}

if (!isset($_GET['auxil'])) {
   $auxil = "";
   $where = "descri like '".addslashes($auxil)."%'";
}
?>
<div align="center" class="FacetFormHeaderFont">Raggruppamenti statistici</div>
<?php
$recordnav = new recordnav($gTables['ragstat'], $where, $limit, $passo);
$recordnav -> output();

/** ENRICO FEDELE */
/* pulizia del codice, eliminato boxover, aggiunte classi bootstrap alla tabella, convertite immagini in glyphicons */
?>
<form method="GET" action="<?php echo $_SERVER['PHP_SELF']; ?>">
<table class="Tlarge table table-striped table-bordered table-condensed table-responsive">
    <thead>
        <tr>
        	<td></td>
        	<td class="FacetFieldCaptionTD">Descrizione:
        		<input type="text" name="auxil" value="<?php if ($auxil != "&all=yes") echo $auxil; ?>" maxlength="6" tabindex="1" class="FacetInput">
        	</td>
        	<td>
        		<input type="submit" name="search" value="Cerca" tabindex="1" onClick="javascript:document.report.all.value=1;">
        	</td>
        	<td>
        		<input type="submit" name="all" value="Mostra tutti" onClick="javascript:document.report.all.value=1;">
        	</td>
        </tr>
        <tr>
<?php
$result = gaz_dbi_dyn_query ('*', $gTables['ragstat'], $where, $orderby, $limit, $passo);
// creo l'array (header => campi) per l'ordinamento dei record
$headers_ragstat = array  (
            "Codice" => "codice",
            "Descrizione" => "descri",
            "% Ricarico" => "ricarico",
            "Annotazioni" => "annota",
            "Cancella" => ""
            );
$linkHeaders = new linkHeaders($headers_ragstat);
$linkHeaders -> output();
?>
		</tr>
	</thead>
	<tbody>
<?php
while ($a_row = gaz_dbi_fetch_array($result)) {
    /*if(!isset($_GET['all']) and !empty($a_row["image"])){
            $boxover = "title=\"cssbody=[FacetInput] cssheader=[FacetButton] header=[{$a_row['annota']}] body=[<center><img src='../root/view.php?table=ragstat&value=".$a_row['codice']."'>] fade=[on] fadespeed=[0.03] \"";
    } else {
            $boxover = "title=\"cssbody=[FacetInput] cssheader=[FacetButton] header=[{$a_row['annota']}]  fade=[on] fadespeed=[0.03] \"";
    }*/
    echo '		<tr>
				<td class="FacetDataTD">
					<a class="btn btn-xs btn-default btn-block" href="admin_ragstat.php?Update&codice='.$a_row["codice"].'">
						<i class="glyphicon glyphicon-edit"></i>&nbsp;'.$a_row["codice"].'
					</a>
				</td>
				<td class="FacetDataTD">
					<span class="gazie-tooltip" data-type="ragstat-thumb" data-id="'.$a_row['codice'].'" data-title="'.$a_row['annota'].'">'.$a_row["descri"].'</span>
				</td>
				<td class="FacetDataTD">'.$a_row["ricarico"].'</td>
				<td class="FacetDataTD">'.$a_row["annota"].'</td>
				<td class="FacetDataTD">
					<a class="btn btn-xs btn-default btn-elimina" href="delete_ragstat.php?codice='.$a_row["codice"].'">
						<i class="glyphicon glyphicon-remove"></i>
					</a>
				</td>
			</tr>';
}
?>
			</tbody>
		</table>
	<?php
require("../../library/include/footer.php");
?>
<!--<script src="../../js/boxover/boxover.js"></script>-->
